.. AUTO-GENERATED FILE -- DO NOT EDIT!

models.model_spec
=================

Module: :mod:`models.model_spec`
--------------------------------
Inheritance diagram for ``ISLP.models.model_spec``:

.. inheritance-diagram:: ISLP.models.model_spec 
   :parts: 3

.. automodule:: ISLP.models.model_spec

.. currentmodule:: ISLP.models.model_spec

Classes
-------

:class:`Contrast`
~~~~~~~~~~~~~~~~~


.. autoclass:: Contrast
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`Feature`
~~~~~~~~~~~~~~~~


.. autoclass:: Feature
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`ModelSpec`
~~~~~~~~~~~~~~~~~~


.. autoclass:: ModelSpec
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

Functions
---------


.. autofunction:: ISLP.models.model_spec.bs


.. autofunction:: ISLP.models.model_spec.build_columns


.. autofunction:: ISLP.models.model_spec.build_model


.. autofunction:: ISLP.models.model_spec.contrast


.. autofunction:: ISLP.models.model_spec.derived_feature


.. autofunction:: ISLP.models.model_spec.fit_encoder


.. autofunction:: ISLP.models.model_spec.ns


.. autofunction:: ISLP.models.model_spec.ordinal


.. autofunction:: ISLP.models.model_spec.pca


.. autofunction:: ISLP.models.model_spec.poly

